==> crux-dev-5.1.0.jar: org/cruxframework/crux/core/rebind/screen/widget/creator/event/PageEvtBind.java <==
/*
 * Copyright 2011 cruxframework.org.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.cruxframework.crux.core.rebind.screen.widget.creator.event;

import org.cruxframework.crux.core.client.datasource.pager.PageEvent;
import org.cruxframework.crux.core.client.datasource.pager.PageHandler;
import org.cruxframework.crux.core.rebind.screen.widget.EvtProcessor;
import org.cruxframework.crux.core.rebind.screen.widget.WidgetCreator;

/**
 * Helper Class for beforeSelection events binding
 * @author Thiago da Rosa de Bustamante
 *
 */
public class PageEvtBind extends EvtProcessor
{
	public PageEvtBind(WidgetCreator<?> widgetCreator)
    {
	    super(widgetCreator);
    }

	private static final String EVENT_NAME = "onPage";

	/**
	 * @see org.cruxframework.crux.core.rebind.screen.widget.EvtProcessor#getEventName()
	 */
	public String getEventName()
	{
		return EVENT_NAME;
	}

	
	@Override
	public Class<?> getEventClass()
	{
	    return PageEvent.class;
	}

	@Override
    public Class<?> getEventHandlerClass()
    {
	    return PageHandler.class;
    }
}

==> crux-dev-5.3.2.jar: org/cruxframework/crux/core/rebind/screen/widget/creator/event/PageEvtBind.java <==
/*
 * Copyright 2011 cruxframework.org.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.cruxframework.crux.core.rebind.screen.widget.creator.event;

import org.cruxframework.crux.core.client.dataprovider.pager.PageEvent;
import org.cruxframework.crux.core.client.dataprovider.pager.PageHandler;
import org.cruxframework.crux.core.rebind.screen.widget.EvtProcessor;
import org.cruxframework.crux.core.rebind.screen.widget.WidgetCreator;

/**
 * Helper Class for beforeSelection events binding
 * @author Thiago da Rosa de Bustamante
 *
 */
public class PageEvtBind extends EvtProcessor
{
	public PageEvtBind(WidgetCreator<?> widgetCreator)
    {
	    super(widgetCreator);
    }

	private static final String EVENT_NAME = "onPage";

	/**
	 * @see org.cruxframework.crux.core.rebind.screen.widget.EvtProcessor#getEventName()
	 */
	public String getEventName()
	{
		return EVENT_NAME;
	}

	
	@Override
	public Class<?> getEventClass()
	{
	    return PageEvent.class;
	}

	@Override
    public Class<?> getEventHandlerClass()
    {
	    return PageHandler.class;
    }
}
